<?php
/**
 * Ratio Lite Theme Customizer
 *
 * @package Ratio_Lite
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function ratio_lite_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'ratio_lite_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'ratio_lite_customize_partial_blogdescription',
		) );
	}
}
add_action( 'customize_register', 'ratio_lite_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function ratio_lite_customize_partial_blogname() {
	echo esc_html(get_bloginfo('name'));
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function ratio_lite_customize_partial_blogdescription() {
		echo esc_html(get_bloginfo('description'));
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function ratio_lite_customize_preview_js() {
	wp_enqueue_script( 'ratio-lite-customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'ratio_lite_customize_preview_js' );

/* Costomizie Upgrade Pro*/

function ratio_lite_customize_scripts() {
	wp_enqueue_script( 'ratio_lite_customizer_custom', get_template_directory_uri() . '/js/ratio-lite-customizer-custom-scripts.min.js', array( 'jquery' ), '20131028', true );
	
	$ratio_lite_misc_links = array(
							'upgrade_link' 				=> esc_url( 'https://themesvila.com/item/ratio/' ),
							'upgrade_text'	 			=> esc_html__( 'Upgrade To Pro &raquo;', 'ratio-lite' ),
		);

	//Add Upgrade Button and old WordPress message via localized script
	wp_localize_script( 'ratio_lite_customizer_custom', 'ratio_lite_misc_links', $ratio_lite_misc_links );

	wp_enqueue_style( 'ratio_lite_customizer_custom', get_template_directory_uri() . '/css/ratio-lite-customizer.css');
}
add_action( 'customize_controls_enqueue_scripts', 'ratio_lite_customize_scripts');